// src/index.ts
import { getQueriesForElement, prettyDOM } from "@testing-library/dom";
import { createComponent, createRoot, getOwner } from "solid-js";
import { hydrate as solidHydrate, render as solidRender } from "solid-js/web";
export * from "@testing-library/dom";
if (!process.env.STL_SKIP_AUTO_CLEANUP) {
  if (typeof afterEach === "function") {
    afterEach(async () => {
      await cleanup();
    });
  }
}
var mountedContainers = /* @__PURE__ */ new Set();
function render(ui, options = {}) {
  let { container, baseElement = container, queries, hydrate = false, wrapper } = options;
  if (!baseElement) {
    baseElement = document.body;
  }
  if (!container) {
    container = baseElement.appendChild(document.createElement("div"));
  }
  const wrappedUi = typeof wrapper === "function" ? () => createComponent(wrapper, { get children() {
    return createComponent(ui, {});
  } }) : ui;
  const dispose = hydrate ? solidHydrate(wrappedUi, container) : solidRender(wrappedUi, container);
  mountedContainers.add({ container, dispose });
  const queryHelpers = getQueriesForElement(container, queries);
  return {
    asFragment: () => container?.innerHTML,
    container,
    baseElement,
    debug: (el = baseElement, maxLength, options2) => Array.isArray(el) ? el.forEach((e) => console.log(prettyDOM(e, maxLength, options2))) : console.log(prettyDOM(el, maxLength, options2)),
    unmount: dispose,
    ...queryHelpers
  };
}
function renderHook(hook, options) {
  const initialProps = Array.isArray(options) ? options : options?.initialProps || [];
  const [dispose, owner, result] = createRoot((dispose2) => [dispose2, getOwner(), hook(...initialProps)]);
  mountedContainers.add({ dispose });
  return { result, cleanup: dispose, owner };
}
function cleanupAtContainer(ref) {
  const { container, dispose } = ref;
  dispose();
  if (container?.parentNode === document.body) {
    document.body.removeChild(container);
  }
  mountedContainers.delete(ref);
}
function cleanup() {
  mountedContainers.forEach(cleanupAtContainer);
}
export {
  cleanup,
  render,
  renderHook
};
